[Bf-extensions-cvs] SVN commit: /data/svn/bf-extensions [1415] trunk/py/scripts/addons/ render_povray: Unified the spelling of POV-Ray (official spelling)

Constantin Rahn conz at vrchannel.de
Sun Jan 16 18:35:41 CET 2011


Revision: 1415
          http://projects.blender.org/plugins/scmsvn/viewcvs.php?view=rev&root=bf-extensions&revision=1415
Author:   conz
Date:     2011-01-16 17:35:41 +0000 (Sun, 16 Jan 2011)
Log Message:
-----------
Unified the spelling of POV-Ray (official spelling)

Modified Paths:
--------------
    trunk/py/scripts/addons/render_povray/__init__.py
    trunk/py/scripts/addons/render_povray/render.py
    trunk/py/scripts/addons/render_povray/ui.py

Modified: trunk/py/scripts/addons/render_povray/__init__.py
===================================================================
--- trunk/py/scripts/addons/render_povray/__init__.py	2011-01-16 09:07:17 UTC (rev 1414)
+++ trunk/py/scripts/addons/render_povray/__init__.py	2011-01-16 17:35:41 UTC (rev 1415)
@@ -17,14 +17,14 @@
 # ##### END GPL LICENSE BLOCK #####
 
 bl_info = {
-    "name": "PovRay 3.7",
+    "name": "POV-Ray 3.7",
     "author": "Campbell Barton, Silvio Falcinelli, Maurice Raybaud, Constantin Rahn",
     "version": (0, 0, 6),
     "blender": (2, 5, 6),
     "api": 34318,
     "location": "Info Header (engine dropdown)",
-    "description": "Basic povray 3.7 integration for blender",
-    "warning": "both povray 3.7 and this script are beta",
+    "description": "Basic POV-Ray 3.7 integration for blender",
+    "warning": "both POV-Ray 3.7 and this script are beta",
     "wiki_url": "http://wiki.blender.org/index.php/Extensions:2.5/Py/"\
         "Scripts/Render/PovRay",
     "tracker_url": "https://projects.blender.org/tracker/index.php?"\
@@ -49,7 +49,7 @@
     # Not a real pov option, just to know if we should write
     Scene.pov_radio_enable = BoolProperty(
             name="Enable Radiosity",
-            description="Enable povrays radiosity calculation",
+            description="Enable POV-Rays radiosity calculation",
             default=False)
     Scene.pov_radio_display_advanced = BoolProperty(
             name="Advanced Options",
@@ -57,7 +57,7 @@
             default=False)
     Scene.pov_media_enable = BoolProperty(
         name="Enable Media",
-        description="Enable povrays atmospheric media",
+        description="Enable POV-Rays atmospheric media",
         default=False)
     Scene.pov_media_samples = IntProperty(
             name="Samples", description="Number of samples taken from camera to first object encountered along ray path for media calculation",
@@ -67,7 +67,7 @@
             min=0.00, max=1.00, soft_min=0.01, soft_max=1.00, default=0.01)
     Scene.pov_baking_enable = BoolProperty(
             name="Enable Baking",
-            description="Enable povrays texture baking",
+            description="Enable POV-Rays texture baking",
             default=False)
     Scene.pov_indentation_character = EnumProperty(
             name="Indentation",

Modified: trunk/py/scripts/addons/render_povray/render.py
===================================================================
--- trunk/py/scripts/addons/render_povray/render.py	2011-01-16 09:07:17 UTC (rev 1414)
+++ trunk/py/scripts/addons/render_povray/render.py	2011-01-16 17:35:41 UTC (rev 1415)
@@ -63,8 +63,8 @@
     if ts.mapping=='FLAT':image_map= ' map_type 0 ' 
     if ts.mapping=='SPHERE':image_map= ' map_type 1 '# map_type 7 in megapov
     if ts.mapping=='TUBE':image_map= ' map_type 2 '
-    #if ts.mapping=='?':image_map= ' map_type 3 '# map_type 3 and 4 in development (?) for Povray, currently they just seem to default back to Flat (type 0)
-    #if ts.mapping=='?':image_map= ' map_type 4 '# map_type 3 and 4 in development (?) for Povray, currently they just seem to default back to Flat (type 0)
+    #if ts.mapping=='?':image_map= ' map_type 3 '# map_type 3 and 4 in development (?) for POV-Ray, currently they just seem to default back to Flat (type 0)
+    #if ts.mapping=='?':image_map= ' map_type 4 '# map_type 3 and 4 in development (?) for POV-Ray, currently they just seem to default back to Flat (type 0)
     if ts.texture.use_interpolation: image_map+= ' interpolate 2 '
     if ts.texture.extension == 'CLIP': image_map+=' once '
     #image_map+='}'
@@ -301,7 +301,7 @@
 
 
             if material:
                 #Povray 3.7 now uses two diffuse values respectively for front and back shading (the back diffuse is like blender translucency)
                 frontDiffuse=material.diffuse_intensity
                 backDiffuse=material.translucency
                 
@@ -329,11 +329,11 @@
                 #####################################Diffuse Shader######################################
                 # Not used for Full spec (Level=3) of the shader
                 if material.diffuse_shader == 'OREN_NAYAR' and Level != 3:
-                    tabWrite('brilliance %.3g\n' % (0.9+material.roughness))#blender roughness is what is generally called oren nayar Sigma, and brilliance in povray
+                    tabWrite('brilliance %.3g\n' % (0.9+material.roughness))#blender roughness is what is generally called oren nayar Sigma, and brilliance in POV-Ray
 
                 if material.diffuse_shader == 'TOON' and Level != 3:
                     tabWrite('brilliance %.3g\n' % (0.01+material.diffuse_toon_smooth*0.25))
-                    frontDiffuse*=0.5 #Lower diffuse and increase specular for toon effect seems to look better in povray
+                    frontDiffuse*=0.5 #Lower diffuse and increase specular for toon effect seems to look better in POV-Ray
                 
                 if material.diffuse_shader == 'MINNAERT' and Level != 3:
                     #tabWrite('aoi %.3g\n' % material.darkness)
@@ -350,7 +350,7 @@
                         tabWrite('phong %.3g\n' % (material.specular_intensity))
                         tabWrite('phong_size %.3g\n'% (material.specular_hardness / 2 + 0.25)) 
 
-                    if material.specular_shader == 'BLINN':#Povray 'specular' keyword corresponds to a Blinn model, without the ior.
+                    if material.specular_shader == 'BLINN':#POV-Ray 'specular' keyword corresponds to a Blinn model, without the ior.
                         tabWrite('specular %.3g\n' % (material.specular_intensity * (material.specular_ior/4))) #Use blender Blinn's IOR just as some factor for spec intensity
                         tabWrite('roughness %.3g\n' % roughness) 
                         #Could use brilliance 2(or varying around 2 depending on ior or factor) too.
@@ -377,10 +377,10 @@
 
 
                 tabWrite('ambient %.3g\n' % material.ambient)
-                #tabWrite('ambient rgb <%.3g, %.3g, %.3g>\n' % tuple([c*material.ambient for c in world.ambient_color])) # povray blends the global value
-                tabWrite('emission %.3g\n' % material.emit) #New in povray 3.7
+                #tabWrite('ambient rgb <%.3g, %.3g, %.3g>\n' % tuple([c*material.ambient for c in world.ambient_color])) # POV-Ray blends the global value
+                tabWrite('emission %.3g\n' % material.emit) #New in POV-Ray 3.7
                 
                 #tabWrite('roughness %.3g\n' % roughness) #povray just ignores roughness if there's no specular keyword
                 
                 if material.pov_conserve_energy:
                     tabWrite('conserve_energy\n')#added for more realistic shading. Needs some checking to see if it really works. --Maurice.
@@ -1283,7 +1283,7 @@
         for material in bpy.data.materials:
             if material.subsurface_scattering.use and once:
                 tabWrite('mm_per_unit %.6f\n' % (material.subsurface_scattering.scale * (-100) + 15))#In pov, the scale has reversed influence compared to blender. these number should correct that
-                once=0 #In povray, the scale factor for all subsurface shaders needs to be the same
+                once=0 #In POV-Ray, the scale factor for all subsurface shaders needs to be the same
 
         if world: 
             tabWrite('ambient_light rgb<%.3g, %.3g, %.3g>\n' % tuple(world.ambient_color))
@@ -1301,7 +1301,7 @@
         
     sel = scene.objects
     comments = scene.pov_comments_enable
-    if comments: file.write('//---------------------------------------------\n//--Exported with Povray exporter for Blender--\n//---------------------------------------------\n')
+    if comments: file.write('//---------------------------------------------\n//--Exported with POV-Ray exporter for Blender--\n//---------------------------------------------\n')
     if comments: file.write('\n//--Global settings and background--\n\n')
     
     exportGlobalSettings(scene)
@@ -1375,12 +1375,12 @@
 
     file.write('Display=1\n')#Activated (turn this back off when better live exchange is done between the two programs (see next comment)
     file.write('Pause_When_Done=0\n')
-    file.write('Output_File_Type=N\n') # PNG, with POV 3.7, can show background color with alpha. In the long run using the Povray interactive preview like bishop 3D could solve the preview for all formats. 
+    file.write('Output_File_Type=N\n') # PNG, with POV-Ray 3.7, can show background color with alpha. In the long run using the POV-Ray interactive preview like bishop 3D could solve the preview for all formats. 
     #file.write('Output_File_Type=T\n') # TGA, best progressive loading
     file.write('Output_Alpha=1\n')
 
     if render.use_antialiasing:
-        aa_mapping = {'5': 2, '8': 3, '11': 4, '16': 5} # method 2 (recursive) with higher max subdiv forced because no mipmapping in povray needs higher sampling.
+        aa_mapping = {'5': 2, '8': 3, '11': 4, '16': 5} # method 2 (recursive) with higher max subdiv forced because no mipmapping in POV-Ray needs higher sampling.
         file.write('Antialias=on\n')
         file.write('Sampling_Method=2\n')
         file.write('Antialias_Depth=%d\n' % aa_mapping[render.antialiasing_samples])
@@ -1397,7 +1397,7 @@
 
 class PovrayRender(bpy.types.RenderEngine):
     bl_idname = 'POVRAY_RENDER'
-    bl_label = 'Povray 3.7'
+    bl_label = 'POV-Ray 3.7'
     DELAY = 0.05
     
     def _export(self, scene):
@@ -1405,18 +1405,18 @@
         
         # mktemp is Deprecated since version 2.3, replaced with NamedTemporaryFile() #CR
         self._temp_file_in = tempfile.NamedTemporaryFile(suffix='.pov', delete=False)
-        self._temp_file_out = tempfile.NamedTemporaryFile(suffix='.png', delete=False)#PNG with POV 3.7, can show the background color with alpha. In the long run using the Povray interactive preview like bishop 3D could solve the preview for all formats.

@@ Diff output truncated at 10240 characters. @@
@@ -301,7 +301,7 @@
 
             if material:
-                #Povray 3.7 now uses two diffuse values respectively for front and back shading (the back diffuse is like blender translucency)
+                #POV-Ray 3.7 now uses two diffuse values respectively for front and back shading (the back diffuse is like blender translucency)
                 frontDiffuse=material.diffuse_intensity
                 backDiffuse=material.translucency
@@ -377,10 +377,10 @@
                 
-                #tabWrite('roughness %.3g\n' % roughness) #povray just ignores roughness if there's no specular keyword
+                #tabWrite('roughness %.3g\n' % roughness) #POV-Ray just ignores roughness if there's no specular keyword
                 
                 if material.pov_conserve_energy:


More information about the Bf-extensions-cvs mailing list